Prepared rewrite of framework bootstrap:
[core.git] / index.php
index 0a3ef741158afd0be661a3d36b0c1b63d8e4c89b..b54c766135e0d55fd599451842699bb3280acb6a 100644 (file)
--- a/index.php
+++ b/index.php
@@ -183,24 +183,32 @@ final class ApplicationEntryPoint {
        }
 
        /**
* The application's main entry point. This class isolates some local
         * variables which shall not become visible to outside because of security
-        * concerns. We are doing this here to "emulate" the well-known entry
-        * point in Java.
+        * concerns. This is done here to "emulate" the well-known entry point in
+        * Java.
         *
         * @return      void
         */
        public static final function main () {
// Load config file
                require(self::detectCorePath() . '/inc/config.php');
 
+               // Get a new configuration instance
+               $cfg = FrameworkConfiguration::getSelfInstance();
+
+               // Load bootstrap class
+               require($cfg->getConfigEntry('base_path') . 'inc/bootstrap/class_BootstrapFramework.php');
+
+               // ----- Below is deprecated -----
+
                // Load all include files
                require($cfg->getConfigEntry('base_path') . 'inc/includes.php');
 
                // Include the application selector
                require($cfg->getConfigEntry('base_path') . 'inc/selector.php');
-       } // END - main()
-} // END - class
+       }
+}
 
 // Developer mode active? Comment out if no dev!
 define('DEVELOPER', TRUE);
@@ -210,7 +218,7 @@ define('DEVELOPER', TRUE);
 
 //xdebug_start_trace();
 
-// Do not remove the following line:
+// Call above main() method
 ApplicationEntryPoint::main();
 
 // [EOF]
@@ -183,24 +183,32 @@ final class ApplicationEntryPoint {
 
        /**
-        * The application's main entry point. This class isolates some local
+        * The framework's main entry point. This class isolates some local
         * variables which shall not become visible to outside because of security
@@ -183,24 +183,32 @@ final class ApplicationEntryPoint {
         */
        public static final function main () {
-               // Load config file
+               // Load config file, this provides $cfg
                require(self::detectCorePath() . '/inc/config.php');
 